@@ -22,7 +22,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 $Params::Check::VERBOSE = 1;
 
-=head1 NAME 
+=head1 NAME
 
 CPANPLUS::Internals::Source::Memory - In memory implementation
 
@@ -36,7 +36,7 @@ CPANPLUS::Internals::Source::Memory - In memory implementation
         my $self = shift;
         my $conf = $self->configure_object;
         my %hash = @_;
-    
+
         my($path,$uptodate,$verbose,$use_stored);
         my $tmpl = {
             path        => { default => $conf->get_conf('base'), store => \$path },
@@ -44,21 +44,21 @@ CPANPLUS::Internals::Source::Memory - In memory implementation
             uptodate    => { required => 1, store => \$uptodate },
             use_stored  => { default  => 1, store => \$use_stored },
         };
-    
+
         check( $tmpl, \%hash ) or return;
-    
+
         ### retrieve the stored source files ###
         my $stored      = $self->__memory_retrieve_source(
                                 path        => $path,
                                 uptodate    => $uptodate && $use_stored,
                                 verbose     => $verbose,
                             ) || {};
-    
+
         ### we got this from storable if $stored has keys..
         $from_storable = keys %$stored ? 1 : 0;
-    
+
         ### set up the trees
-        $self->_atree( $stored->{_atree} || {} );                    
+        $self->_atree( $stored->{_atree} || {} );
         $self->_mtree( $stored->{_mtree} || {} );
 
         return 1;
@@ -71,7 +71,7 @@ CPANPLUS::Internals::Source::Memory - In memory implementation
         my $self = shift;
         my $conf = $self->configure_object;
         my %hash = @_;
-    
+
         my($path,$uptodate,$verbose);
         my $tmpl = {
             path        => { default => $conf->get_conf('base'), store => \$path },
@@ -79,34 +79,34 @@ CPANPLUS::Internals::Source::Memory - In memory implementation
             uptodate    => { required => 1, store => \$uptodate },
         };
 
-        {   local $Params::Check::ALLOW_UNKNOWN = 1;    
+        {   local $Params::Check::ALLOW_UNKNOWN = 1;
             check( $tmpl, \%hash ) or return;
         }
-        
+
         ### write the stored files to disk, so we can keep using them
         ### from now on, till they become invalid
         ### write them if the original sources weren't uptodate, or
         ### we didn't just load storable files
         $self->__memory_save_source() if !$uptodate or not $from_storable;
-    
+
         return 1;
     }
-    
+
     ### saves current memory state
     sub _save_state {
         my $self = shift;
         return $self->_finalize_trees( @_, uptodate => 0 );
-    }        
+    }
 }
 
 sub _add_author_object {
     my $self = shift;
     my %hash = @_;
-    
+
     my $class;
     my $tmpl = {
         class   => { default => 'CPANPLUS::Module::Author', store => \$class },
-        map { $_ => { required => 1 } } 
+        map { $_ => { required => 1 } }
             qw[ author cpanid email ]
     };
 
@@ -114,53 +114,59 @@ sub _add_author_object {
         local $Params::Check::NO_DUPLICATES = 1;
         check( $tmpl, \%hash ) or return;
     };
-    
+
     my $obj = $class->new( %$href, _id => $self->_id );
-    
+
     $self->author_tree->{ $href->{'cpanid'} } = $obj or return;
 
     return $obj;
 }
 
-sub _add_module_object {
-    my $self = shift;
-    my %hash = @_;
+{
+    my @required_opts = map { $_ => { required => 1 } } qw[
+        module version path comment author package description dslip mtime
+    ];
 
-    my $class;    
-    my $tmpl = {
-        class   => { default => 'CPANPLUS::Module', store => \$class },
-        map { $_ => { required => 1 } } 
-            qw[ module version path comment author package description dslip mtime ]
-    };
+    sub _add_module_object {
+        my $self = shift;
+        my %hash = @_;
 
-    my $href = do {
-        local $Params::Check::NO_DUPLICATES = 1;
-        check( $tmpl, \%hash ) or return;
-    };
-    
-    my $obj = $class->new( %$href, _id => $self->_id );
-    
-    ### Every module get's stored as a module object ###
-    $self->module_tree->{ $href->{module} } = $obj or return;
+        my $class;
+        my $tmpl = {
+            class   => { default => 'CPANPLUS::Module', store => \$class },
+            @required_opts,
+        };
 
-    return $obj;    
+        my $href = do {
+            local $Params::Check::NO_DUPLICATES = 1;
+            local $Params::Check::SANITY_CHECK_TEMPLATE = 0;
+            check( $tmpl, \%hash ) or return;
+        };
+
+        my $obj = $class->new( %$href, _id => $self->_id );
+
+        ### Every module get's stored as a module object ###
+        $self->module_tree->{ $href->{module} } = $obj or return;
+
+        return $obj;
+    }
 }
 
 {   my %map = (
         _source_search_module_tree  => [ module_tree => 'CPANPLUS::Module' ],
         _source_search_author_tree  => [ author_tree => 'CPANPLUS::Module::Author' ],
-    );        
+    );
 
     while( my($sub, $aref) = each %map ) {
         no strict 'refs';
-        
+
         my($meth, $class) = @$aref;
-        
+
         *$sub = sub {
             my $self = shift;
             my $conf = $self->configure_object;
             my %hash = @_;
-        
+
             my($authors,$list,$verbose,$type);
             my $tmpl = {
                 data    => { default    => [],
@@ -172,9 +178,9 @@ sub _add_module_object {
                 type    => { required   => 1, allow => [$class->accessors()],
                              store      => \$type },
             };
-        
-            my $args = check( $tmpl, \%hash ) or return;            
-        
+
+            my $args = check( $tmpl, \%hash ) or return;
+
             my @rv;
             for my $obj ( values %{ $self->$meth } ) {
                 #push @rv, $auth if check(
@@ -182,8 +188,8 @@ sub _add_module_object {
                 #                        { $type => $auth->$type }
                 #                    );
                 push @rv, $obj if allow( $obj->$type() => $list );
-            }        
-        
+            }
+
             return @rv;
         }
     }
@@ -343,16 +349,18 @@ sub __memory_storable_file {
                         : 0;
 
     return unless $storable;
-    
+
     ### $stored is the name of the frozen data structure ###
     ### changed to use File::Spec->catfile -jmb
     my $stored = File::Spec->rel2abs(
         File::Spec->catfile(
             $path,                          #base dir
             $conf->_get_source('stored')    #file
-            . '.' .
-            $Storable::VERSION              #the version of storable 
-            . '.stored'                     #append a suffix
+            . '.s' .
+            $Storable::VERSION              #the version of storable
+            . '.c' .
+            $self->VERSION                  #the version of CPANPLUS
+            . STORABLE_EXT                  #append a suffix
         )
     );
 
